searchData={"items":[{"type":"module","title":"Enfiladex","doc":"`Enfiladex` is the drop-in `Common Test` wrapper for _ExUnit_. It also exposes functions\nto run some code on a freshly started remote node.\n\nAll one needs to evaluate the code on one or more of connected nodes, would be to\ncall a function exported from this module.\n\nKnown config parameters:\n\n- **`transfer_config`** (default: `true`) — whether the configuration of application(s)\n  should be transferred to the started nodes, accepts `boolean() | atom()` where `atom()`\n  is the application name besides already loaded the config is to be transferred for,\n  normally it’s the main application configuration  \n- **`start_applications`** (default: `true`) — `boolean() | atom()` specifying whether\n  the application(s) should have been starter on the spawned node(s)\n- **`nodes`** (default: `3`) — for `multi_peer/3`, the number of nodes to start","ref":"Enfiladex.html"},{"type":"function","title":"Enfiladex.multi_peer/3","doc":"Executes the function given as first argument on several newly spawned nodes, with options\n  passed as `config` argument.\n  \nIt would call `Callback(Result)` for each result on each node, if `callback` passed before\n  stopping the peer. The order is not guaranteed.","ref":"Enfiladex.html#multi_peer/3"},{"type":"function","title":"Enfiladex.peer/3","doc":"Executes the function given as first argument on the newly spawned node, with options\n  passed as `config` argument.\n\nIt would call `Callback(Result)` if `callback` passed before stopping the peer.","ref":"Enfiladex.html#peer/3"},{"type":"type","title":"Enfiladex.callback/0","doc":"The callback to be called on the result on the remote node(s)","ref":"Enfiladex.html#t:callback/0"},{"type":"type","title":"Enfiladex.callback_return_value/0","doc":"","ref":"Enfiladex.html#t:callback_return_value/0"},{"type":"type","title":"Enfiladex.callee/0","doc":"The function to be passed for execution on the remote node(s)","ref":"Enfiladex.html#t:callee/0"},{"type":"type","title":"Enfiladex.callee_return_value/0","doc":"","ref":"Enfiladex.html#t:callee_return_value/0"},{"type":"module","title":"Enfiladex.Suite","doc":"`use Enfiladex` is the drop-in `Common Test` wrapper for _ExUnit_.\n\n\n> ### `use Enfiladex.Suite` {: .info}\n>\n> When you `use Enfiladex.Suite`, the tests in the case become available to use with `common_test`:\n>\n> - calls to `setup/2` and `setup_all/2` are also injected as `init_per_***/2` and `end_per_***/2`\n> - `groups/0` and `all/0` are injectd based on your `describe/2` and `test/2` calls \n\n\n\n**`@enfiladex_strategy`** attribute can be set before each `describe/2` call to one of the following values:\n\n- **`[]`** (empty list / no option)\n  - The test cases in the group are run one after the other. If a test fails, the others after it in the list are run.\n- **`:shuffle`**\n  - Runs the test in a random order. The random seed (the initialization value) used for the sequence will be printed in the HTML logs, of the form {A,B,C}. If a particular sequence of tests fails and you want to reproduce it, use that seed in the HTML logs and change the shuffle option to instead be {shuffle, {A,B,C}}. That way you can reproduce random runs in their precise order if you ever need to.\n- **`:parallel`**\n  - The tests are run in different processes. Be careful because if you forget to export the init_per_group and end_per_group functions, Common Test will silently ignore this option.\n- **`:sequence`**\n  - Doesn't necessarily mean that the tests are run in order, but rather that if a test fails in the group's list, then all the other subsequent tests are skipped. This option can be combined with shuffle if you want any random test failing to stop the ones after.\n- **`{:repeat, times}`**\n  - Repeats the group Times times. You could thus run all test cases in the group in parallel 9 times in a row by using the group properties [parallel, {repeat, 9}]. Times can also have the value forever, although 'forever' is a bit of a lie as it can't defeat concepts such as hardware failure or heat death of the Universe (ahem).\n- **`{:repeat_until_any_fail, n}`**\n  - Runs all the tests until one of them fails or they have been run N times. N can also be forever.\n- **`{:repeat_until_all_fail, n}`**\n  - Same as above, but the tests may run until all cases fail.\n- **`{:repeat_until_any_succeed, n}`**\n  - Same as before, except the tests may run until at least one case succeeds.\n- **`{:repeat_until_all_succeed, n}`**\n  - I think you can guess this one by yourself now, but just in case, it's the same as before except that the test cases may run until they all succeed.\n\n[Common Test for Uncommon Tests](https://learnyousomeerlang.com/common-test-for-uncommon-tests)","ref":"Enfiladex.Suite.html"},{"type":"task","title":"mix enfiladex","doc":"Mix task to run `commot_test` with `ExUnit` test files.","ref":"Mix.Tasks.Enfiladex.html"},{"type":"function","title":"Mix.Tasks.Enfiladex.run/1","doc":"","ref":"Mix.Tasks.Enfiladex.html#run/1"},{"type":"exception","title":"Enfiladex.ModuleAttributeError","doc":"Exception raised to indicate the misplaced module attribute.","ref":"Enfiladex.ModuleAttributeError.html"},{"type":"type","title":"Enfiladex.ModuleAttributeError.t/0","doc":"","ref":"Enfiladex.ModuleAttributeError.html#t:t/0"},{"type":"extras","title":"Enfiladex","doc":"# Enfiladex\n\n**Wrapper for executing `ExUnit` as `common_test` **","ref":"readme.html"},{"type":"extras","title":"Installation - Enfiladex","doc":"```elixir\ndef deps do\n  [\n    {:enfiladex, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Enfiladex","doc":"Add `use Enfiladex` to your test to convert it to common test suite.","ref":"readme.html#usage"},{"type":"extras","title":"Known issues - Enfiladex","doc":"- `on_exit/2` callbacks with captures makes test to fail compiling with `use Enfiladex` (`Code.with_diagnostics/2` issue),\n- `Enfiladex.{peer/3, multi_peer_/3}` fail from tests with an anonymous function,\n- ~~`MIX_ENV=test iex --sname am -S mix enfiladex` (named node) to execute common test,~~\n- ~~compiled `beam` files are not yet removed.~~\n\n[Documentation](https://hexdocs.pm/enfiladex).","ref":"readme.html#known-issues"}],"content_type":"text/markdown"}